Shell command parsing: tree-sitter AST, shlex tokenizer, pipeline types. Shell command parsing: tree-sitter-bash AST, shlex tokenizer, and pipeline types.
This module provides three layers:
shell— tree-sitter-bash AST walker that decomposes commands into segments, operators, substitutions, and redirections.tokenize— shlex-based word splitting, base command extraction, and env var parsing.types— data types shared between the parser and evaluator.
Re-exports
pub use shell::dump_ast;pub use shell::has_output_redirection;pub use shell::parse_with_substitutions;pub use tokenize::base_command;pub use tokenize::env_vars;pub use tokenize::tokenize;pub use types::Operator;pub use types::ParsedPipeline;pub use types::Redirection;pub use types::ShellSegment;
Modules
- shell
- tree-sitter-bash AST walker for compound command splitting. Shell command parsing backed by tree-sitter-bash.
- tokenize
- shlex-based tokenization: word splitting, base command extraction, env var parsing.
- types
- Shared types:
ParsedPipeline,ShellSegment,Operator,Redirection. Types produced by the shell parser and consumed by the eval layer.