pub trait CommandSpec: Send + Sync {
// Required method
fn evaluate(&self, ctx: &CommandContext) -> RuleMatch;
}Expand description
Trait for command evaluation specs.
Each implementation knows how to evaluate a specific command (or family of commands)
and returns a RuleMatch with the decision and reason.
Required Methods
Sourcefn evaluate(&self, ctx: &CommandContext) -> RuleMatch
fn evaluate(&self, ctx: &CommandContext) -> RuleMatch
Evaluate the command in the given context and return a decision.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".