pub trait CommandSpec: Send + Sync {
// Required method
fn evaluate(&self, ctx: &CommandContext<'_>) -> RuleMatch;
}Expand description
Trait for command evaluation specs.
Each implementation knows how to evaluate a specific command (or family of commands)
and returns a RuleMatch with the decision and reason.
Required Methods
Sourcefn evaluate(&self, ctx: &CommandContext<'_>) -> RuleMatch
fn evaluate(&self, ctx: &CommandContext<'_>) -> RuleMatch
Evaluate the command in the given context and return a decision.