pub fn evaluate(command: &str) -> RuleMatchExpand description
Build the registry from default config and evaluate a command string.
This is the main entry point for tests and simple usage. For CLI usage with –escalate-deny or user config, build the registry directly.